__all__ = ["DiscordWebhookHandler"]
import logging
from logging import LogRecord

import requests


class DiscordWebhookHandler(logging.Handler):
    def __init__(self, webhook_url: str, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.webhook_url = webhook_url

    def emit(self, record: LogRecord) -> None:
        requests.post(self.webhook_url, json={"content": self.format(record)})



__all__ = ["DiscordFormatter"]

import logging
import typing
import traceback
from logging import LogRecord


LEVEL_TO_EMOJI = {
    logging.DEBUG: "white_check_mark",
    logging.INFO: "information_source",
    logging.WARNING: "warning",
    logging.ERROR: "bangbang",
    logging.CRITICAL: "bangbang",
}


class DiscordFormatter(logging.Formatter):
    def __init__(self, user_id_to_alert: typing.Optional[str] = None):
        self.user_id_to_alert = user_id_to_alert

    def format(self, record: LogRecord) -> str:
        header = f":{LEVEL_TO_EMOJI[record.levelno]}: **{record.levelname}**"
        if record.levelno >= logging.ERROR:
            header += f" <@{self.user_id_to_alert}>"

        header += '\n'

        body = f"> {record.msg}\n"

        if record.exc_info:
            _, exc, _ = record.exc_info
            body += f"```{traceback.format_exc()}```"

        return header + body



__all__ = ["get_discord_logger"]

import logging
import typing

from .formatters import DiscordFormatter
from .handlers import DiscordWebhookHandler


def get_discord_logger(
    name: str, webhook_url: str, username: typing.Optional[str] = None
):
    logger = logging.getLogger(name)
    handler = DiscordWebhookHandler(webhook_url)
    formatter = DiscordFormatter(username)
    handler.setFormatter(formatter)
    logger.addHandler(handler)
    return logger
